==> qtjambi-macextras-5.15.9-sources.jar: io/qt/macextras/QMacToolBar.java <==
package io.qt.macextras;


/**
 * <p>Wraps the native NSToolbar class</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qmactoolbar.html">QMacToolBar</a></p>
 */
public class QMacToolBar extends io.qt.core.QObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QMacToolBar.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #QMacToolBar(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QMacToolBar() {
        this((io.qt.core.QObject)null);
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qmactoolbar.html#QMacToolBar">QMacToolBar::QMacToolBar(QObject*)</a></p>
     */
    public QMacToolBar(io.qt.core.QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QMacToolBar instance, io.qt.core.QObject parent);
    
    /**
     * <p>Overloaded constructor for {@link #QMacToolBar(java.lang.String, io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QMacToolBar(java.lang.String identifier) {
        this(identifier, (io.qt.core.QObject)null);
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qmactoolbar.html#QMacToolBar-1">QMacToolBar::QMacToolBar(QString,QObject*)</a></p>
     */
    public QMacToolBar(java.lang.String identifier, io.qt.core.QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, identifier, parent);
    }
    
    private native static void initialize_native(QMacToolBar instance, java.lang.String identifier, io.qt.core.QObject parent);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qmactoolbar.html#addAllowedItem">QMacToolBar::addAllowedItem(QIcon,QString)</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.macextras.QMacToolBarItem addAllowedItem(io.qt.gui.QIcon icon, java.lang.String text){
        return addAllowedItem_native_cref_QIcon_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(icon), text);
    }
    
    @io.qt.QtUninvokable
    private native io.qt.macextras.QMacToolBarItem addAllowedItem_native_cref_QIcon_cref_QString(long __this__nativeId, long icon, java.lang.String text);
    
    @io.qt.QtUninvokable
    public final io.qt.macextras.QMacToolBarItem addAllowedStandardItem(io.qt.macextras.QMacToolBarItem.StandardItem standardItem){
        return addAllowedStandardItem_native_QMacToolBarItem_StandardItem(QtJambi_LibraryUtilities.internal.nativeId(this), standardItem.value());
    }
    
    @io.qt.QtUninvokable
    private native io.qt.macextras.QMacToolBarItem addAllowedStandardItem_native_QMacToolBarItem_StandardItem(long __this__nativeId, int standardItem);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qmactoolbar.html#addItem">QMacToolBar::addItem(QIcon,QString)</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.macextras.QMacToolBarItem addItem(io.qt.gui.QIcon icon, java.lang.String text){
        return addItem_native_cref_QIcon_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(icon), text);
    }
    
    @io.qt.QtUninvokable
    private native io.qt.macextras.QMacToolBarItem addItem_native_cref_QIcon_cref_QString(long __this__nativeId, long icon, java.lang.String text);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qmactoolbar.html#addSeparator">QMacToolBar::addSeparator()</a></p>
     */
    @io.qt.QtUninvokable
    public final void addSeparator(){
        addSeparator_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void addSeparator_native(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final io.qt.macextras.QMacToolBarItem addStandardItem(io.qt.macextras.QMacToolBarItem.StandardItem standardItem){
        return addStandardItem_native_QMacToolBarItem_StandardItem(QtJambi_LibraryUtilities.internal.nativeId(this), standardItem.value());
    }
    
    @io.qt.QtUninvokable
    private native io.qt.macextras.QMacToolBarItem addStandardItem_native_QMacToolBarItem_StandardItem(long __this__nativeId, int standardItem);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qmactoolbar.html#allowedItems">QMacToolBar::allowedItems()</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.core.QList<io.qt.macextras.QMacToolBarItem> allowedItems(){
        return allowedItems_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QList<io.qt.macextras.QMacToolBarItem> allowedItems_native(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qmactoolbar.html#attachToWindow">QMacToolBar::attachToWindow(QWindow*)</a></p>
     */
    @io.qt.QtUninvokable
    public final void attachToWindow(io.qt.gui.QWindow window){
        attachToWindow_native_QWindow_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(window));
    }
    
    @io.qt.QtUninvokable
    private native void attachToWindow_native_QWindow_ptr(long __this__nativeId, long window);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qmactoolbar.html#detachFromWindow">QMacToolBar::detachFromWindow()</a></p>
     */
    @io.qt.QtUninvokable
    public final void detachFromWindow(){
        detachFromWindow_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void detachFromWindow_native(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qmactoolbar.html#items">QMacToolBar::items()</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.core.QList<io.qt.macextras.QMacToolBarItem> items(){
        return items_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QList<io.qt.macextras.QMacToolBarItem> items_native(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qmactoolbar.html#setAllowedItems">QMacToolBar::setAllowedItems(QList&lt;QMacToolBarItem*&gt;&amp;)</a></p>
     */
    @io.qt.QtUninvokable
    public final void setAllowedItems(java.util.Collection<? extends io.qt.macextras.QMacToolBarItem> allowedItems){
        setAllowedItems_native_ref_QList(QtJambi_LibraryUtilities.internal.nativeId(this), allowedItems);
    }
    
    @io.qt.QtUninvokable
    private native void setAllowedItems_native_ref_QList(long __this__nativeId, java.util.Collection<? extends io.qt.macextras.QMacToolBarItem> allowedItems);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qmactoolbar.html#setItems">QMacToolBar::setItems(QList&lt;QMacToolBarItem*&gt;&amp;)</a></p>
     */
    @io.qt.QtUninvokable
    public final void setItems(java.util.Collection<? extends io.qt.macextras.QMacToolBarItem> items){
        setItems_native_ref_QList(QtJambi_LibraryUtilities.internal.nativeId(this), items);
    }
    
    @io.qt.QtUninvokable
    private native void setItems_native_ref_QList(long __this__nativeId, java.util.Collection<? extends io.qt.macextras.QMacToolBarItem> items);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QMacToolBar(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QMacToolBar(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QMacToolBar instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-macextras-5.15.14-sources.jar: io/qt/macextras/QMacToolBar.java <==
package io.qt.macextras;

import io.qt.*;


/**
 * <p>Wraps the native NSToolbar class</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qmactoolbar.html">QMacToolBar</a></p>
 */
public class QMacToolBar extends io.qt.core.QObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QMacToolBar.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QMacToolBar() {
        this((io.qt.core.QObject)null);
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qmactoolbar.html#QMacToolBar">QMacToolBar::QMacToolBar(QObject*)</a></p>
     */
    public QMacToolBar(io.qt.core.@Nullable QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QMacToolBar instance, io.qt.core.QObject parent);
    
    /**
     * <p>Overloaded constructor for {@link #(java.lang.String, io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QMacToolBar(java.lang.@NonNull String identifier) {
        this(identifier, (io.qt.core.QObject)null);
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qmactoolbar.html#QMacToolBar-1">QMacToolBar::QMacToolBar(QString,QObject*)</a></p>
     */
    public QMacToolBar(java.lang.@NonNull String identifier, io.qt.core.@Nullable QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, identifier, parent);
    }
    
    private native static void initialize_native(QMacToolBar instance, java.lang.String identifier, io.qt.core.QObject parent);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qmactoolbar.html#addAllowedItem">QMacToolBar::addAllowedItem(QIcon,QString)</a></p>
     */
    @QtUninvokable
    public final io.qt.macextras.@Nullable QMacToolBarItem addAllowedItem(io.qt.gui.@NonNull QIcon icon, java.lang.@NonNull String text){
        return addAllowedItem_native_cref_QIcon_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(icon), text);
    }
    
    @QtUninvokable
    private native io.qt.macextras.QMacToolBarItem addAllowedItem_native_cref_QIcon_cref_QString(long __this__nativeId, long icon, java.lang.String text);
    
    @QtUninvokable
    public final io.qt.macextras.@Nullable QMacToolBarItem addAllowedStandardItem(io.qt.macextras.QMacToolBarItem.@NonNull StandardItem standardItem){
        return addAllowedStandardItem_native_QMacToolBarItem_StandardItem(QtJambi_LibraryUtilities.internal.nativeId(this), standardItem.value());
    }
    
    @QtUninvokable
    private native io.qt.macextras.QMacToolBarItem addAllowedStandardItem_native_QMacToolBarItem_StandardItem(long __this__nativeId, int standardItem);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qmactoolbar.html#addItem">QMacToolBar::addItem(QIcon,QString)</a></p>
     */
    @QtUninvokable
    public final io.qt.macextras.@Nullable QMacToolBarItem addItem(io.qt.gui.@NonNull QIcon icon, java.lang.@NonNull String text){
        return addItem_native_cref_QIcon_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(icon), text);
    }
    
    @QtUninvokable
    private native io.qt.macextras.QMacToolBarItem addItem_native_cref_QIcon_cref_QString(long __this__nativeId, long icon, java.lang.String text);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qmactoolbar.html#addSeparator">QMacToolBar::addSeparator()</a></p>
     */
    @QtUninvokable
    public final void addSeparator(){
        addSeparator_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void addSeparator_native(long __this__nativeId);
    
    @QtUninvokable
    public final io.qt.macextras.@Nullable QMacToolBarItem addStandardItem(io.qt.macextras.QMacToolBarItem.@NonNull StandardItem standardItem){
        return addStandardItem_native_QMacToolBarItem_StandardItem(QtJambi_LibraryUtilities.internal.nativeId(this), standardItem.value());
    }
    
    @QtUninvokable
    private native io.qt.macextras.QMacToolBarItem addStandardItem_native_QMacToolBarItem_StandardItem(long __this__nativeId, int standardItem);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qmactoolbar.html#allowedItems">QMacToolBar::allowedItems()</a></p>
     */
    @QtUninvokable
    public final io.qt.core.@NonNull QList<io.qt.macextras.@Nullable QMacToolBarItem> allowedItems(){
        return allowedItems_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QList<io.qt.macextras.QMacToolBarItem> allowedItems_native(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qmactoolbar.html#attachToWindow">QMacToolBar::attachToWindow(QWindow*)</a></p>
     */
    @QtUninvokable
    public final void attachToWindow(io.qt.gui.@Nullable QWindow window){
        attachToWindow_native_QWindow_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(window));
    }
    
    @QtUninvokable
    private native void attachToWindow_native_QWindow_ptr(long __this__nativeId, long window);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qmactoolbar.html#detachFromWindow">QMacToolBar::detachFromWindow()</a></p>
     */
    @QtUninvokable
    public final void detachFromWindow(){
        detachFromWindow_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void detachFromWindow_native(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qmactoolbar.html#items">QMacToolBar::items()</a></p>
     */
    @QtUninvokable
    public final io.qt.core.@NonNull QList<io.qt.macextras.@Nullable QMacToolBarItem> items(){
        return items_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QList<io.qt.macextras.QMacToolBarItem> items_native(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qmactoolbar.html#setAllowedItems">QMacToolBar::setAllowedItems(QList&lt;QMacToolBarItem*&gt;&amp;)</a></p>
     */
    @QtUninvokable
    public final void setAllowedItems(java.util.@NonNull Collection<? extends io.qt.macextras.@Nullable QMacToolBarItem> allowedItems){
        setAllowedItems_native_ref_QList(QtJambi_LibraryUtilities.internal.nativeId(this), allowedItems);
    }
    
    @QtUninvokable
    private native void setAllowedItems_native_ref_QList(long __this__nativeId, java.util.Collection<? extends io.qt.macextras.QMacToolBarItem> allowedItems);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qmactoolbar.html#setItems">QMacToolBar::setItems(QList&lt;QMacToolBarItem*&gt;&amp;)</a></p>
     */
    @QtUninvokable
    public final void setItems(java.util.@NonNull Collection<? extends io.qt.macextras.@Nullable QMacToolBarItem> items){
        setItems_native_ref_QList(QtJambi_LibraryUtilities.internal.nativeId(this), items);
    }
    
    @QtUninvokable
    private native void setItems_native_ref_QList(long __this__nativeId, java.util.Collection<? extends io.qt.macextras.QMacToolBarItem> items);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @NativeAccess
    protected QMacToolBar(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @NativeAccess
    protected QMacToolBar(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QMacToolBar instance, QDeclarativeConstructor constructor);
    
}
